@@ -12,7 +12,8 @@
 
 import os
 
-import six
+from debtcollector import removals
+from keystoneauth1 import plugin
 import stevedore
 
 from keystoneclient import exceptions
@@ -21,12 +22,17 @@ from keystoneclient import exceptions
 # NOTE(jamielennox): The AUTH_INTERFACE is a special value that can be
 # requested from get_endpoint. If a plugin receives this as the value of
 # 'interface' it should return the initial URL that was passed to the plugin.
-AUTH_INTERFACE = object()
+AUTH_INTERFACE = plugin.AUTH_INTERFACE
 
 PLUGIN_NAMESPACE = 'keystoneclient.auth.plugin'
 IDENTITY_AUTH_HEADER_NAME = 'X-Auth-Token'
 
 
+@removals.remove(
+    message='keystoneclient auth plugins are deprecated. Use keystoneauth.',
+    version='2.1.0',
+    removal_version='3.0.0'
+)
 def get_available_plugin_names():
     """Get the names of all the plugins that are available on the system.
 
@@ -41,6 +47,11 @@ def get_available_plugin_names():
     return frozenset(mgr.names())
 
 
+@removals.remove(
+    message='keystoneclient auth plugins are deprecated. Use keystoneauth.',
+    version='2.1.0',
+    removal_version='3.0.0'
+)
 def get_available_plugin_classes():
     """Retrieve all the plugin classes available on the system.
 
@@ -55,6 +66,11 @@ def get_available_plugin_classes():
     return dict(mgr.map(lambda ext: (ext.entry_point.name, ext.plugin)))
 
 
+@removals.remove(
+    message='keystoneclient auth plugins are deprecated. Use keystoneauth.',
+    version='2.1.0',
+    removal_version='3.0.0'
+)
 def get_plugin_class(name):
     """Retrieve a plugin class by its entrypoint name.
 
@@ -235,7 +251,7 @@ class BaseAuthPlugin(object):
 
         :returns: A list of Param objects describing available plugin
                   parameters.
-        :rtype: list
+        :rtype: List
         """
         return []
 
@@ -259,7 +275,6 @@ class BaseAuthPlugin(object):
         :param parser: the parser to attach argparse options.
         :type parser: argparse.ArgumentParser
         """
-
         # NOTE(jamielennox): ideally oslo_config would be smart enough to
         # handle all the Opt manipulation that goes on in this file. However it
         # is currently not.  Options are handled in as similar a way as
@@ -276,7 +291,7 @@ class BaseAuthPlugin(object):
 
             # select the first ENV that is not false-y or return None
             env_vars = (os.environ.get(e) for e in envs)
-            default = six.next(six.moves.filter(None, env_vars), None)
+            default = next(filter(None, env_vars), None)
 
             parser.add_argument(*args,
                                 default=default or opt.default,
@@ -296,7 +311,6 @@ class BaseAuthPlugin(object):
         :returns: An auth plugin, or None if a name is not provided.
         :rtype: :py:class:`keystoneclient.auth.BaseAuthPlugin`
         """
-
         def _getter(opt):
             return getattr(namespace, 'os_%s' % opt.dest)
 
@@ -326,7 +340,6 @@ class BaseAuthPlugin(object):
         :returns: An authentication Plugin.
         :rtype: :py:class:`keystoneclient.auth.BaseAuthPlugin`
         """
-
         def _getter(opt):
             return conf[group][opt.dest]
 
@@ -334,7 +347,7 @@ class BaseAuthPlugin(object):
 
     @classmethod
     def load_from_options_getter(cls, getter, **kwargs):
-        """Load a plugin from a getter function that returns appropriate values
+        """Load a plugin from a getter function returning appropriate values.
 
         To handle cases other than the provided CONF and CLI loading you can
         specify a custom loader function that will be queried for the option
@@ -349,7 +362,6 @@ class BaseAuthPlugin(object):
         :returns: An authentication Plugin.
         :rtype: :py:class:`keystoneclient.auth.BaseAuthPlugin`
         """
-
         plugin_opts = cls.get_options()
 
         for opt in plugin_opts:
