@@ -14,8 +14,7 @@ import abc
 import logging
 
 from oslo_config import cfg
-from positional import positional
-import six
+from oslo_serialization import jsonutils
 
 from keystoneclient import access
 from keystoneclient.auth.identity import base
@@ -27,12 +26,11 @@ _logger = logging.getLogger(__name__)
 __all__ = ('Auth', 'AuthMethod', 'AuthConstructor', 'BaseAuth')
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseAuth(base.BaseIdentityPlugin):
+class BaseAuth(base.BaseIdentityPlugin, metaclass=abc.ABCMeta):
     """Identity V3 Authentication Plugin.
 
     :param string auth_url: Identity service endpoint for authentication.
-    :param list auth_methods: A collection of methods to authenticate with.
+    :param List auth_methods: A collection of methods to authenticate with.
     :param string trust_id: Trust ID for trust scoping.
     :param string domain_id: Domain ID for domain scoping.
     :param string domain_name: Domain name for domain scoping.
@@ -46,7 +44,6 @@ class BaseAuth(base.BaseIdentityPlugin):
                                  token. (optional) default True.
     """
 
-    @positional()
     def __init__(self, auth_url,
                  trust_id=None,
                  domain_id=None,
@@ -110,7 +107,7 @@ class Auth(BaseAuth):
     """Identity V3 Authentication Plugin.
 
     :param string auth_url: Identity service endpoint for authentication.
-    :param list auth_methods: A collection of methods to authenticate with.
+    :param List auth_methods: A collection of methods to authenticate with.
     :param string trust_id: Trust ID for trust scoping.
     :param string domain_id: Domain ID for domain scoping.
     :param string domain_name: Domain name for domain scoping.
@@ -190,6 +187,7 @@ class Auth(BaseAuth):
                             authenticated=False, log=False, **rkwargs)
 
         try:
+            _logger.debug(jsonutils.dumps(resp.json()))
             resp_data = resp.json()['token']
         except (KeyError, ValueError):
             raise exceptions.InvalidResponse(response=resp)
@@ -198,8 +196,7 @@ class Auth(BaseAuth):
                                    **resp_data)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AuthMethod(object):
+class AuthMethod(object, metaclass=abc.ABCMeta):
     """One part of a V3 Authentication strategy.
 
     V3 Tokens allow multiple methods to be presented when authentication
@@ -233,7 +230,7 @@ class AuthMethod(object):
 
         :param session: The communication session.
         :type session: keystoneclient.session.Session
-        :param Auth auth: The auth plugin calling the method.
+        :param base.Auth auth: The auth plugin calling the method.
         :param dict headers: The headers that will be sent with the auth
                              request if a plugin needs to add to them.
         :return: The identifier of this plugin and a dict of authentication
@@ -243,8 +240,7 @@ class AuthMethod(object):
         pass  # pragma: no cover
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AuthConstructor(Auth):
+class AuthConstructor(Auth, metaclass=abc.ABCMeta):
     """Abstract base class for creating an Auth Plugin.
 
     The Auth Plugin created contains only one authentication method. This
