@@ -28,7 +28,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                     "password"
                 ],
 
-                "expires_at": "2020-01-01T00:00:10.000123Z",
+                "expires_at": "2999-01-01T00:00:10.000123Z",
                 "project": {
                     "domain": {
                         "id": self.TEST_DOMAIN_ID,
@@ -222,7 +222,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                                auth_url=self.TEST_URL)
         self.assertEqual(cs.auth_token,
                          self.TEST_RESPONSE_HEADERS["X-Subject-Token"])
-        self.assertFalse('catalog' in cs.service_catalog.catalog)
+        self.assertNotIn('catalog', cs.service_catalog.catalog)
         self.assertRequestBodyIs(json=self.TEST_REQUEST_BODY)
 
     def test_auth_url_token_authentication(self):
@@ -232,7 +232,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
 
         self.stub_auth(json=self.TEST_RESPONSE_DICT)
         self.stub_url('GET', [fake_url], json=fake_resp,
-                      base_url=self.TEST_ADMIN_IDENTITY_ENDPOINT)
+                      base_url=self.TEST_PUBLIC_IDENTITY_ENDPOINT)
 
         # Creating a HTTPClient not using session is deprecated.
         with self.deprecations.expect_deprecations_here():
@@ -241,8 +241,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
         body = jsonutils.loads(self.requests_mock.last_request.body)
         self.assertEqual(body['auth']['identity']['token']['id'], fake_token)
 
-        with self.deprecations.expect_deprecations_here():
-            resp, body = cl.get(fake_url)
+        resp, body = cl._adapter.get(fake_url)
         self.assertEqual(fake_resp, body)
 
         token = self.requests_mock.last_request.headers.get('X-Auth-Token')
@@ -326,7 +325,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                                auth_url=self.TEST_URL)
         self.assertEqual(cs.auth_token,
                          self.TEST_RESPONSE_HEADERS["X-Subject-Token"])
-        self.assertFalse('catalog' in cs.service_catalog.catalog)
+        self.assertNotIn('catalog', cs.service_catalog.catalog)
         self.assertRequestBodyIs(json=self.TEST_REQUEST_BODY)
 
     def test_allow_override_of_auth_token(self):
@@ -336,7 +335,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
 
         self.stub_auth(json=self.TEST_RESPONSE_DICT)
         self.stub_url('GET', [fake_url], json=fake_resp,
-                      base_url=self.TEST_ADMIN_IDENTITY_ENDPOINT)
+                      base_url=self.TEST_PUBLIC_IDENTITY_ENDPOINT)
 
         # Creating a HTTPClient not using session is deprecated.
         with self.deprecations.expect_deprecations_here():
@@ -348,8 +347,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
         self.assertEqual(cl.auth_token, self.TEST_TOKEN)
 
         # the token returned from the authentication will be used
-        with self.deprecations.expect_deprecations_here():
-            resp, body = cl.get(fake_url)
+        resp, body = cl._adapter.get(fake_url)
         self.assertEqual(fake_resp, body)
 
         token = self.requests_mock.last_request.headers.get('X-Auth-Token')
@@ -358,8 +356,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
         # then override that token and the new token shall be used
         cl.auth_token = fake_token
 
-        with self.deprecations.expect_deprecations_here():
-            resp, body = cl.get(fake_url)
+        resp, body = cl._adapter.get(fake_url)
         self.assertEqual(fake_resp, body)
 
         token = self.requests_mock.last_request.headers.get('X-Auth-Token')
@@ -368,8 +365,7 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
         # if we clear that overridden token then we fall back to the original
         del cl.auth_token
 
-        with self.deprecations.expect_deprecations_here():
-            resp, body = cl.get(fake_url)
+        resp, body = cl._adapter.get(fake_url)
         self.assertEqual(fake_resp, body)
 
         token = self.requests_mock.last_request.headers.get('X-Auth-Token')
